@@ -37,7 +37,9 @@ public:
              WFlags fl=0);
   ~QBEditUser();
 
-  static bool editUser(QBanking *kb, AB_USER *u, QWidget* parent=0);
+  bool fromGui(bool doLock);
+
+  static bool editUser(QBanking *kb, AB_USER *u, bool doLock, QWidget* parent=0);
 
 };
 
