@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbpickstartdate.cpp 837 2006-01-23 16:31:01Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -26,6 +26,7 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qbuttongroup.h>
 
 
 
@@ -57,12 +58,12 @@ QBPickStartDate::QBPickStartDate(QBanking *qb,
     lastUpdateLabel->setText(_lastUpdate.toString());
     lastUpdateButton->setEnabled(true);
     lastUpdateLabel->setEnabled(true);
-    if (defaultChoice==2)
-      defaultChoice=1;
   }
   else {
     lastUpdateButton->setEnabled(false);
     lastUpdateLabel->setEnabled(false);
+    if (defaultChoice==2)
+      defaultChoice=1;
   }
 
   if (_firstPossible.isValid()) {
@@ -86,6 +87,7 @@ QBPickStartDate::QBPickStartDate(QBanking *qb,
 
   pickDateEdit->setDate(QDate::currentDate());
 
+  buttonGroup->setFocus();
 }
 
 
@@ -125,6 +127,8 @@ QDate QBPickStartDate::getDate() {
     return _firstPossible;
   else if (pickDateButton->isChecked())
     return pickDateEdit->date();
+  else if (lastUpdateButton->isChecked())
+    return _lastUpdate;
   else {
     DBG_ERROR(0, "Unknown date state");
     return QDate();
