@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: qbselectbank.h 837 2006-01-23 16:31:01Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -19,7 +19,7 @@ class QBanking;
 
 #include "qbselectbank.ui.h"
 #include <aqbanking/bankinfo.h>
-#include <qbanking/banking.h> /* For QBANKING_API */
+#include <qbanking/qbanking.h> /* For QBANKING_API */
 #include <string>
 
 
