@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbcfgmodule.cpp 764 2006-01-13 14:00:00Z cstim $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,7 +25,9 @@
 QBCfgModule::QBCfgModule(QBanking *qb, const QString &name)
 :_qbanking(qb)
 ,_name(name)
-,_plugin(0){
+,_plugin(0)
+,_flags(0)
+{
 
 }
 
@@ -74,26 +76,26 @@ const QString &QBCfgModule::getName() const {
 
 
 
-GWEN_TYPE_UINT32 QBCfgModule::getFlags() const {
+uint32_t QBCfgModule::getFlags() const {
   return _flags;
 }
 
 
 
-void QBCfgModule::setFlags(GWEN_TYPE_UINT32 fl) {
+void QBCfgModule::setFlags(uint32_t fl) {
   _flags=fl;
 }
 
 
 
 int QBCfgModule::createNewUser(QWidget *parent) {
-  return AB_ERROR_NOT_SUPPORTED;
+  return GWEN_ERROR_NOT_SUPPORTED;
 }
 
 
 
 int QBCfgModule::createNewAccount(QWidget *parent) {
-  return AB_ERROR_NOT_SUPPORTED;
+  return GWEN_ERROR_NOT_SUPPORTED;
 }
 
 
