@@ -29,6 +29,7 @@
 #include "jobs/jobsingletransfer_l.h"
 #include "jobs/jobsingledebitnote_l.h"
 #include "jobs/jobeutransfer_l.h"
+#include "jobs/jobsepatransfer_l.h"
 #include "jobs/jobcreatesto_l.h"
 #include "jobs/jobmodifysto_l.h"
 #include "jobs/jobdeletesto_l.h"
@@ -70,7 +71,7 @@ AB_JOB *AB_Job_new(AB_JOB_TYPE jt, AB_ACCOUNT *a){
   GWEN_INHERIT_INIT(AB_JOB, j);
   GWEN_LIST_INIT(AB_JOB, j);
 
-  j->jobId=AB_Banking_GetUniqueId(ab);
+  j->jobId=AB_Banking_GetUniqueId(ab, 0);
   j->jobType=jt;
   j->account=a;
 
@@ -256,6 +257,8 @@ const char *AB_Job_Type2Char(AB_JOB_TYPE i) {
   case AB_Job_TypeDeleteDatedTransfer: s="deletedatedtransfer"; break;
   case AB_Job_TypeInternalTransfer:    s="internaltransfer"; break;
   case AB_Job_TypeLoadCellPhone:       s="loadCellPhone"; break;
+  case AB_Job_TypeSepaTransfer:        s="sepaTransfer"; break;
+  case AB_Job_TypeSepaDebitNote:       s="sepaDebitNote"; break;
   default:
   case AB_Job_TypeUnknown:             s="unknown"; break;
   }
@@ -284,6 +287,8 @@ const char *AB_Job_Type2LocalChar(AB_JOB_TYPE i) {
   case AB_Job_TypeDeleteDatedTransfer: s=I18N("Delete Dated Transfer"); break;
   case AB_Job_TypeInternalTransfer:    s=I18N("Internal Transfer"); break;
   case AB_Job_TypeLoadCellPhone:       s=I18N("Load Cellphone"); break;
+  case AB_Job_TypeSepaTransfer:        s=I18N("SEPA Transfer"); break;
+  case AB_Job_TypeSepaDebitNote:       s=I18N("SEPA Debit Note"); break;
   default:
   case AB_Job_TypeUnknown:             s=I18N("unknown"); break;
   }
@@ -297,12 +302,18 @@ AB_JOB_TYPE AB_Job_Char2Type(const char *s) {
   AB_JOB_TYPE i;
 
   if (strcasecmp(s, "getbalance")==0) i=AB_Job_TypeGetBalance;
-  else if (strcasecmp(s, "gettransactions")==0) i=AB_Job_TypeGetTransactions;
-  else if (strcasecmp(s, "transfer")==0) i=AB_Job_TypeTransfer;
-  else if (strcasecmp(s, "debitnote")==0) i=AB_Job_TypeDebitNote;
-  else if (strcasecmp(s, "eutransfer")==0) i=AB_Job_TypeEuTransfer;
-  else if (strcasecmp(s, "getstandingorders")==0) i=AB_Job_TypeGetStandingOrders;
-  else if (strcasecmp(s, "getdatedtransfers")==0) i=AB_Job_TypeGetDatedTransfers;
+  else if (strcasecmp(s, "gettransactions")==0)
+    i=AB_Job_TypeGetTransactions;
+  else if (strcasecmp(s, "transfer")==0)
+    i=AB_Job_TypeTransfer;
+  else if (strcasecmp(s, "debitnote")==0)
+    i=AB_Job_TypeDebitNote;
+  else if (strcasecmp(s, "eutransfer")==0)
+    i=AB_Job_TypeEuTransfer;
+  else if (strcasecmp(s, "getstandingorders")==0)
+    i=AB_Job_TypeGetStandingOrders;
+  else if (strcasecmp(s, "getdatedtransfers")==0)
+    i=AB_Job_TypeGetDatedTransfers;
   else if (strcasecmp(s, "createstandingorder")==0)
     i=AB_Job_TypeCreateStandingOrder;
   else if (strcasecmp(s, "modifystandingorder")==0)
@@ -319,6 +330,8 @@ AB_JOB_TYPE AB_Job_Char2Type(const char *s) {
     i=AB_Job_TypeInternalTransfer;
   else if (strcasecmp(s, "loadCellPhone")==0)
     i=AB_Job_TypeLoadCellPhone;
+  else if (strcasecmp(s, "sepaTransfer")==0) i=AB_Job_TypeSepaTransfer;
+  else if (strcasecmp(s, "sepaDebitNote")==0) i=AB_Job_TypeSepaDebitNote;
 
   else i=AB_Job_TypeUnknown;
 
@@ -349,16 +362,22 @@ AB_ACCOUNT *AB_Job_GetAccount(const AB_JOB *j){
 
 
 
-AB_JOB *AB_Job__freeAll_cb(AB_JOB *j, void *userData) {
+void AB_Job_List2_FreeAll(AB_JOB_LIST2 *jl){
+  AB_Job_List2_ClearAll(jl);
+  AB_Job_List2_free(jl);
+}
+
+
+
+AB_JOB *AB_Job__clearAll_cb(AB_JOB *j, void *userData) {
   AB_Job_free(j);
   return 0;
 }
 
 
-
-void AB_Job_List2_FreeAll(AB_JOB_LIST2 *jl){
-  AB_Job_List2_ForEach(jl, AB_Job__freeAll_cb, 0);
-  AB_Job_List2_free(jl);
+void AB_Job_List2_ClearAll(AB_JOB_LIST2 *jl){
+  AB_Job_List2_ForEach(jl, AB_Job__clearAll_cb, 0);
+  AB_Job_List2_Clear(jl);
 }
 
 
