@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: job_l.h 586 2005-09-02 01:57:29Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -26,15 +27,9 @@ GWEN_INHERIT_FUNCTION_DEFS(AB_JOB)
 
 AB_JOB *AB_Job_new(AB_JOB_TYPE jt, AB_ACCOUNT *a);
 
-AB_JOB *AB_Job_new_l(AB_JOB_TYPE jt, AB_ACCOUNT *a);
+int AB_Job_Update(AB_JOB *j, uint32_t guiid);
 
-
-int AB_Job_toDb(const AB_JOB *j, GWEN_DB_NODE *db);
-AB_JOB *AB_Job_fromDb(AB_BANKING *ab, GWEN_DB_NODE *db);
-
-int AB_Job_Update(AB_JOB *j);
-
-void AB_Job_SetUniqueId(AB_JOB *j, GWEN_TYPE_UINT32 jid);
+void AB_Job_SetUniqueId(AB_JOB *j, uint32_t jid);
 
 
 
