@@ -82,6 +82,7 @@ AH_JOB *AH_Job_MultiTransferBase_new(AB_USER *u,
   GWEN_DB_NODE *dbT;
   GWEN_DB_NODE *dbParams;
   const char *s;
+  int userMaxTrans;
 
   j=AH_AccountJob_new(isTransfer?"JobMultiTransfer":"JobMultiDebitNote",
                       u, account);
@@ -128,9 +129,13 @@ AH_JOB *AH_Job_MultiTransferBase_new(AB_USER *u,
 		       isTransfer?"transfer":"debitNote");
 
   dbParams=AH_Job_GetParams(j);
+  if (isTransfer)
+    userMaxTrans=AH_User_GetMaxTransfersPerJob(u);
+  else
+    userMaxTrans=AH_User_GetMaxDebitNotesPerJob(u);
   aj->maxTransfers=GWEN_DB_GetIntValue(dbParams, "maxTransfers", 0, 0);
-  if (aj->maxTransfers==0 || aj->maxTransfers>AH_JOBMULTITRANSFER_MAXTRANS)
-    aj->maxTransfers=AH_JOBMULTITRANSFER_MAXTRANS;
+  if (aj->maxTransfers==0 || aj->maxTransfers>userMaxTrans)
+    aj->maxTransfers=userMaxTrans;
 
   return j;
 }
@@ -485,7 +490,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 	return GWEN_ERROR_INVALID;
       }
       AB_Transaction_SetGroupId(t, AH_Job_GetId(j));
-      DBG_ERROR(0, "Setting groupID to %d", AH_Job_GetId(j));
+      DBG_DEBUG(AQHBCI_LOGDOMAIN, "Setting groupID to %d", AH_Job_GetId(j));
       if (groupIdBuf[0]==0) {
 	snprintf(groupIdBuf, sizeof(groupIdBuf)-1, "%08d", AH_Job_GetId(j));
         groupIdBuf[sizeof(groupIdBuf)-1]=0;
@@ -665,7 +670,7 @@ int AH_Job_MultiTransfer_Prepare(AH_JOB *j, uint32_t guiid){
   GWEN_BUFFER *tbuf;
   char *p;
 
-  DBG_ERROR(0, "Prepare function called");
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Prepare function called");
 
   assert(j);
   aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, j);
