@@ -105,7 +105,7 @@ int AH_Provider_GetServerKeys(AB_PROVIDER *pro, AB_USER *u,
 			      uint32_t guiid);
 
 /**
- * Retrieve the public keys of the given user. This is only needed for
+ * Send the public keys of the given user. This is only needed for
  * PIN/TAN and for RDH mode.
  * @param pro pointer to the HBCI provider
  * @param u user for which the public keys are to be sent
@@ -118,6 +118,23 @@ int AH_Provider_SendUserKeys(AB_PROVIDER *pro, AB_USER *u,
 			     int nounmount,
 			     uint32_t guiid);
 
+/**
+ * Send the public keys of the given user. This is only needed for
+ * PIN/TAN and for RDH mode.
+ * In addition to @ref AH_Provider_SendUserKeys this function also sends the
+ * authentication key if requested.
+ * @param pro pointer to the HBCI provider
+ * @param u user for which the public keys are to be sent
+ * @param nounmount if !=0 then the user's medium is not unmounted in the end.
+ *  This is used by setup wizards to avoid having to enter a pin too often.
+ */
+AQHBCI_API
+int AH_Provider_SendUserKeys2(AB_PROVIDER *pro, AB_USER *u,
+			      AB_IMEXPORTER_CONTEXT *ctx,
+			      int withAuthKey,
+			      int nounmount,
+			      uint32_t guiid);
+
 /**
  * Retrieve the SSL certificate for the given user. This is only needed for
  * PIN/TAN mode.
@@ -175,11 +192,19 @@ int AH_Provider_ChangePin(AB_PROVIDER *pro, AB_USER *u,
 /**
  * Creates a text version of the INI letter. This function needs to mount
  * the medium so the user will be ask for the pin.
+ * @param pro provider
+ * @param u user for which the iniletter is to be created
+ * @param useBankKey if !=0 create an iniletter for the bank key
+ * @param variant use 1 for RDH1, 2 for RDH2-10 (or 0 for autoselection)
+ * @param lbuf buffer to write the iniletter to
+ * @param nounmount if !=0 the CryptToken will not be unmounted after use
+ * @param guiid GUI id in whose context the function is called (for GWEN_Gui_ProgressLog etc)
  */
 AQHBCI_API
 int AH_Provider_GetIniLetterTxt(AB_PROVIDER *pro,
                                 AB_USER *u,
                                 int useBankKey,
+                                int variant,
                                 GWEN_BUFFER *lbuf,
 				int nounmount,
 				uint32_t guiid);
@@ -187,11 +212,19 @@ int AH_Provider_GetIniLetterTxt(AB_PROVIDER *pro,
 /**
  * Creates a HTML version of the INI letter. This function needs to mount
  * the medium so the user will be ask for the pin.
+ * @param pro provider
+ * @param u user for which the iniletter is to be created
+ * @param useBankKey if !=0 create an iniletter for the bank key
+ * @param variant use 1 for RDH1, 2 for RDH2-10 (or 0 for autoselection)
+ * @param lbuf buffer to write the iniletter to
+ * @param nounmount if !=0 the CryptToken will not be unmounted after use
+ * @param guiid GUI id in whose context the function is called (for GWEN_Gui_ProgressLog etc)
  */
 AQHBCI_API
 int AH_Provider_GetIniLetterHtml(AB_PROVIDER *pro,
                                  AB_USER *u,
                                  int useBankKey,
+                                 int variant,
                                  GWEN_BUFFER *lbuf,
 				 int nounmount,
 				 uint32_t guiid);
