@@ -92,7 +92,7 @@ int AH_MsgPinTan_PrepareCryptoSeg(AH_MSG *hmsg,
   else
     GWEN_DB_SetIntValue(cfg, GWEN_DB_FLAGS_DEFAULT,
 			"secProfile/version",
-			(hmsg->itanMethod==998)?1:2);
+			(hmsg->itanMethod==999)?1:2);
 
   return 0;
 }
@@ -149,6 +149,15 @@ int AH_Msg_SignPinTan(AH_MSG *hmsg,
     return GWEN_ERROR_INTERNAL;
   }
 
+  /* for iTAN mode: set selected mode (Sicherheitsfunktion, kodiert) */
+  tm=AH_Msg_GetItanMethod(hmsg);
+  if (tm==0) {
+    tm=AH_Dialog_GetItanMethod(hmsg->dialog);
+    if (tm)
+      /* this is needed by AH_MsgPinTan_PrepareCryptoSeg */
+      AH_Msg_SetItanMethod(hmsg, tm);
+  }
+
   /* prepare config for segment */
   cfg=GWEN_DB_Group_new("sighead");
   rv=AH_MsgPinTan_PrepareCryptoSeg(hmsg, su, cfg, 0, 1);
@@ -182,10 +191,6 @@ int AH_Msg_SignPinTan(AH_MSG *hmsg,
     p="0";
   GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT, "SecDetails/SecId", p);
 
-  /* for iTAN mode: set selected mode (Sicherheitsfunktion, kodiert) */
-  tm=AH_Msg_GetItanMethod(hmsg);
-  if (tm==0)
-    tm=AH_Dialog_GetItanMethod(hmsg->dialog);
   if (tm) {
     GWEN_DB_SetIntValue(cfg, GWEN_DB_FLAGS_DEFAULT,
 			"function", tm);
@@ -241,7 +246,7 @@ int AH_Msg_SignPinTan(AH_MSG *hmsg,
 
   /* handle pin */
   memset(pin, 0, sizeof(pin));
-  rv=AH_User_InputPin(su, pin, 4, sizeof(pin), 0);
+  rv=AH_User_InputPin(su, pin, 4, sizeof(pin), 0, gid);
   if (rv<0) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
 	      "Error getting pin from medium (%d)", rv);
@@ -269,7 +274,7 @@ int AH_Msg_SignPinTan(AH_MSG *hmsg,
 
       memset(tan, 0, sizeof(tan));
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Asking for TAN");
-      rv=AH_User_InputTan(su, tan, 4, sizeof(tan));
+      rv=AH_User_InputTan(su, tan, 4, sizeof(tan), gid);
       if (rv<0) {
 	DBG_ERROR(AQHBCI_LOGDOMAIN, "Error getting TAN from medium");
 	GWEN_DB_Group_free(cfg);
