@@ -114,7 +114,7 @@ int changePin(AB_BANKING *ab,
     return 2;
   }
 
-  rv=AB_Banking_OnlineInit(ab);
+  rv=AB_Banking_OnlineInit(ab, 0);
   if (rv) {
     DBG_ERROR(0, "Error on init (%d)", rv);
     return 2;
@@ -155,14 +155,14 @@ int changePin(AB_BANKING *ab,
     rv=AH_Provider_ChangePin(pro, u, ctx, 0, 0);
     AB_ImExporterContext_free(ctx);
     if (rv) {
-      DBG_ERROR(0, "Error getting list of supported iTAN modes (%d)", rv);
+      DBG_ERROR(0, "Error while changing the PIN (%d)", rv);
       AB_Banking_Fini(ab);
       return 3;
     }
   }
 
 
-  rv=AB_Banking_OnlineFini(ab);
+  rv=AB_Banking_OnlineFini(ab, 0);
   if (rv) {
     fprintf(stderr, "ERROR: Error on deinit (%d)\n", rv);
     return 5;
