@@ -27,15 +27,6 @@
 
 #include "globals.h"
 
-#ifdef WITH_STATIC_PLUGINS
-int GWEN_Plugins_Init();
-int AB_Plugins_Init();
-int LC_Plugins_Init();
-#ifdef ENABLE_EBICS_PLUGINS
-int EBC_Plugins_Init();
-#endif
-#endif
-
 
 
 static void showVersions() {
@@ -224,6 +215,10 @@ int main(int argc, char **argv) {
                              I18N("  delaccount:\n"
                                   "    Deletes account \n\n"));
 
+    GWEN_Buffer_AppendString(ubuf,
+                             I18N("  setMaxTransfers:\n"
+                                  "    Set the maximum number of transfers/debit notes per job \n\n"));
+
     fprintf(stderr, "%s\n", GWEN_Buffer_GetStart(ubuf));
     GWEN_Buffer_free(ubuf);
     return 0;
@@ -233,32 +228,6 @@ int main(int argc, char **argv) {
     argv+=rv-1;
   }
 
-#ifdef WITH_STATIC_PLUGINS
-  rv=GWEN_Plugins_Init();
-  if (rv<0) {
-    fprintf(stderr, "ERROR: Unable to init GWEN plugins (%d).\n", rv);
-    return 1;
-  }
-  rv=LC_Plugins_Init();
-  if (rv<0) {
-    fprintf(stderr, "ERROR: Unable to init Libchipcard plugins (%d).\n", rv);
-    return 1;
-  }
-  rv=AB_Plugins_Init();
-  if (rv<0) {
-    fprintf(stderr, "ERROR: Unable to init AqBanking plugins (%d).\n", rv);
-    return 1;
-  }
-
-#ifdef ENABLE_EBICS_PLUGINS
-  rv=EBC_Plugins_Init();
-  if (rv<0) {
-    fprintf(stderr, "ERROR: Unable to init AqEBICS plugins (%d).\n", rv);
-    return 1;
-  }
-#endif
-#endif
-
   /*GWEN_Logger_SetLevel(AQHBCI_LOGDOMAIN, GWEN_LoggerLevelInfo); */
   cmd=GWEN_DB_GetCharValue(db, "params", 0, 0);
   if (!cmd) {
@@ -363,6 +332,9 @@ int main(int argc, char **argv) {
   else if (strcasecmp(cmd, "subaccountflags")==0) {
     rv=addsubAccountFlags(ab, db, argc, argv, 0);
   }
+  else if (strcasecmp(cmd, "setmaxtransfers")==0) {
+    rv=setMaxTransfers(ab, db, argc, argv);
+  }
   else if (strcasecmp(cmd, "versions")==0) {
     showVersions();
     rv=0;
