@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: cfgmodulehbci.cpp 950 2006-02-22 19:39:02Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -65,7 +65,7 @@ int CfgModuleHbci::createNewUser(QWidget *parent) {
 
   if (dlg.exec())
     return 0;
-  return AB_ERROR_USER_ABORT;
+  return GWEN_ERROR_USER_ABORTED;
 }
 
 
