@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgtabpageaccounthbci.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cfgtabpageaccounthbci.h,v 1.3 2006/01/13 16:51:44 cstim Exp $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
