@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: selectmode.cpp 961 2006-03-07 01:34:24Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -19,6 +19,7 @@
 
 #include <qradiobutton.h>
 #include <qtimer.h>
+#include <qlabel.h> // for qt4 setWordWrap(true)
 #include <gwenhywfar/debug.h>
 
 
@@ -30,6 +31,10 @@ SelectMode::SelectMode(QWidget* parent, const char* name,
 ,_mode(ModeUnknown) {
 
   QTimer::singleShot(0, this, SLOT(adjustSize()));
+#if (QT_VERSION >= 0x040000)
+  // In qt4, QLabel has word-wrap disabled by default
+  textLabel1->setWordWrap(true);
+#endif // QT_VERSION >= 4
 }
 
 
