@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_getcert.cpp 1061 2006-09-19 20:09:45Z christian $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -61,7 +61,7 @@ bool ActionGetCert::apply() {
   u=wInfo->getUser();
   assert(u);
 
-  rv=AH_Provider_GetCert(pro, u, 1);
+  rv=AH_Provider_GetCert(pro, u, 1, 0);
   if (rv) {
     DBG_ERROR(0, "Could not get certificate (%d)", rv);
     return false;
