@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_getkeys.cpp 950 2006-02-22 19:39:02Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -24,6 +24,7 @@
 #include <qbanking/qbanking.h>
 #include <aqhbci/provider.h>
 #include <gwenhywfar/debug.h>
+#include <gwenhywfar/gui.h>
 
 #include <assert.h>
 
@@ -91,7 +92,7 @@ void ActionGetKeys::slotButtonClicked() {
   QBanking *qb;
   AB_USER *u;
   AB_PROVIDER *pro;
-  GWEN_TYPE_UINT32 pid;
+  uint32_t pid;
   int rv;
   AB_IMEXPORTER_CONTEXT *ctx;
 
@@ -106,28 +107,30 @@ void ActionGetKeys::slotButtonClicked() {
 
   _realDialog->setStatus(ActionWidget::StatusChecking);
 
-  pid=qb->progressStart(tr("Getting Server Keys"),
-                        tr("<qt>"
-                           "Retrieving the public keys of the server."
-                           "</qt>"),
-                        1);
   ctx=AB_ImExporterContext_new();
-  rv=AH_Provider_GetServerKeys(pro, u, ctx, 1);
+  pid=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_ALLOW_SUBLEVELS |
+			     GWEN_GUI_PROGRESS_SHOW_PROGRESS |
+			     GWEN_GUI_PROGRESS_KEEP_OPEN |
+			     GWEN_GUI_PROGRESS_SHOW_ABORT,
+			     tr("Getting Server Keys").utf8(),
+			     NULL,
+			     GWEN_GUI_PROGRESS_NONE,
+			     0);
+
+  rv=AH_Provider_GetServerKeys(pro, u, ctx, 1, pid);
+  GWEN_Gui_ProgressEnd(pid);
   AB_ImExporterContext_free(ctx);
   if (rv) {
     DBG_ERROR(0, "Error getting server keys");
     _realDialog->setStatus(ActionWidget::StatusFailed);
-    qb->progressEnd(pid);
     return;
   }
 
-  qb->progressEnd(pid);
-
   _realDialog->setStatus(ActionWidget::StatusSuccess);
   setNextEnabled(true);
 }
 
 
 
-
+#include "a_getkeys.moc"
 
