@@ -45,6 +45,11 @@
 #include <gwenhywfar/gui.h>
 
 
+#define RDH_VERSION_1  0
+#define RDH_VERSION_2  1
+#define RDH_VERSION_10 2
+
+
 
 EditCtUser::EditCtUser(QBanking *qb,
                        WizardInfo *wi,
@@ -62,6 +67,11 @@ EditCtUser::EditCtUser(QBanking *qb,
   showSpecialCheck->setChecked(FALSE);
   specialGroup->hide();
 
+  rdhVersionCombo->clear();
+  rdhVersionCombo->insertItem("1");
+  rdhVersionCombo->insertItem("2");
+  rdhVersionCombo->insertItem("10");
+
   connect(bankCodeButton, SIGNAL(clicked()),
           this, SLOT(slotBankCodeClicked()));
   connect(bankCodeEdit, SIGNAL(lostFocus()),
@@ -169,6 +179,24 @@ void EditCtUser::init() {
       }
     }
 
+    if (_wInfo->getCryptMode()==AH_CryptMode_Rdh) {
+      i=_wInfo->getRdhVersion();
+      switch(i) {
+      case 0:
+      case 1:
+	rdhVersionCombo->setCurrentItem(RDH_VERSION_1);
+	break;
+      case 2:
+	rdhVersionCombo->setCurrentItem(RDH_VERSION_2);
+	break;
+      case 10:
+	rdhVersionCombo->setCurrentItem(RDH_VERSION_10);
+	break;
+      }
+    }
+    else
+      rdhVersionCombo->setEnabled(false);
+
     if (!fromContextCalled) {
       DBG_ERROR(0, "Reading context now");
       _fromContext(0, false);
@@ -244,6 +272,7 @@ bool EditCtUser::apply(){
   std::string peerId;
   int hbciVersion;
   uint32_t userFlags;
+  int rdhMode;
 
   /* do user data page */
 
@@ -255,6 +284,19 @@ bool EditCtUser::apply(){
   default: hbciVersion=210; break;
   }
 
+  switch(rdhVersionCombo->currentItem()) {
+  case RDH_VERSION_2:
+    rdhMode=2;
+    break;
+  case RDH_VERSION_10:
+    rdhMode=10;
+    break;
+  case RDH_VERSION_1:
+  default:
+    rdhMode=1;
+    break;
+  }
+
   /* read ids */
   bankId=QBanking::QStringToUtf8String(bankCodeEdit->text());
   userId=QBanking::QStringToUtf8String(userIdEdit->text());
@@ -501,6 +543,8 @@ bool EditCtUser::apply(){
 
     AH_User_AddFlags(u, userFlags);
 
+    AH_User_SetRdhType(u, rdhMode);
+
     if (!(httpVersion.empty())) {
       int vmajor, vminor;
 
