@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: w_ddv_import.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: w_ddv_import.h,v 1.3 2005/12/01 10:08:02 cstim Exp $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
