@@ -1,7 +1,7 @@
 /***************************************************************************
-  $RCSfile: loganalyzer.cpp,v $
+  $RCSfile$
   -------------------
-  cvs         : $Id: loganalyzer.cpp,v 1.3 2006/01/13 14:00:00 cstim Exp $
+  cvs         : $Id$
   begin       : Sat Oct 25 2003
   copyright   : (C) 2003 by Martin Preuss
   email       : martin@libchipcard.de
@@ -32,11 +32,17 @@
 
 #include "loganalyzer.h"
 
+#include <aqbanking/banking.h>
+
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/directory.h>
 #include <gwenhywfar/path.h>
-#include <gwenhywfar/bufferedio.h>
-#include <gwenhywfar/bio_buffer.h>
+
+#include <gwenhywfar/io_file.h>
+#include <gwenhywfar/io_memory.h>
+#include <gwenhywfar/iolayer.h>
+#include <gwenhywfar/iomanager.h>
+
 
 #ifndef WIN32
 # include <unistd.h>
@@ -76,93 +82,110 @@ LogAnalyzer::LogFile::LogMessage::~LogMessage(){
 
 
 string LogAnalyzer::LogFile::LogMessage::toString() const {
-  GWEN_BUFFEREDIO *bio;
-  GWEN_ERRORCODE err;
-  unsigned int size;
-  const char *p;
-  unsigned int pos;
+  int rv;
+  GWEN_IO_LAYER *io;
   GWEN_BUFFER *buf;
-  string result;
+  std::string result;
 
-  buf=GWEN_Buffer_new(0, 1024, 0, 1);
-  bio=GWEN_BufferedIO_Buffer2_new(buf, 0);
-  GWEN_BufferedIO_SetWriteBuffer(bio, 0, 1024);
-  if (GWEN_DB_WriteToStream(_header, bio,
-                            GWEN_DB_FLAGS_WRITE_SUBGROUPS |
-                            GWEN_DB_FLAGS_DETAILED_GROUPS |
-                            GWEN_DB_FLAGS_USE_COLON|
-                            GWEN_DB_FLAGS_OMIT_TYPES)) {
-    DBG_INFO(0, "called from here");
-    GWEN_BufferedIO_Abandon(bio);
-    GWEN_BufferedIO_free(bio);
+  buf=GWEN_Buffer_new(0, 256, 0, 1);
+
+  /* create io layer for this file */
+  io=GWEN_Io_LayerMemory_new(buf);
+  assert(io);
+
+  rv=GWEN_Io_Manager_RegisterLayer(io);
+  if (rv) {
+    DBG_ERROR(AQBANKING_LOGDOMAIN,
+	      "Internal error: Could not register io layer (%d)", rv);
+    GWEN_Io_Layer_free(io);
     GWEN_Buffer_free(buf);
     return "";
   }
 
-  // append empty line to separate header from data
-  err=GWEN_BufferedIO_WriteLine(bio, "");
-  if (!GWEN_Error_IsOk(err)){
-    DBG_INFO(0, "called from here");
-    GWEN_BufferedIO_Abandon(bio);
-    GWEN_BufferedIO_free(bio);
-    GWEN_Buffer_free(buf);
-    return "";
-  }
-  size=_message.length();
-
-  p=_message.data();
-  pos=0;
-  while(pos<size) {
-    unsigned int lsize;
-
-    lsize=size-pos;
-    err=GWEN_BufferedIO_WriteRaw(bio, p+pos, &lsize);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_INFO(0, "called from here");
-      GWEN_BufferedIO_Abandon(bio);
-      GWEN_BufferedIO_free(bio);
-      GWEN_Buffer_free(buf);
-      return "";
-    }
-    pos+=lsize;
-  } // while
-
-  // append CR for better readability
-  err=GWEN_BufferedIO_WriteLine(bio, "");
-  if (!GWEN_Error_IsOk(err)){
-    DBG_INFO(0, "called from here");
-    GWEN_BufferedIO_Abandon(bio);
-    GWEN_BufferedIO_free(bio);
+  /* write header */
+  rv=GWEN_DB_WriteToIo(_header, io,
+		       GWEN_DB_FLAGS_WRITE_SUBGROUPS |
+		       GWEN_DB_FLAGS_DETAILED_GROUPS |
+		       GWEN_DB_FLAGS_USE_COLON|
+		       GWEN_DB_FLAGS_OMIT_TYPES,
+		       0,
+		       2000);
+  if (rv<0) {
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Io_Layer_free(io);
     GWEN_Buffer_free(buf);
     return "";
   }
 
-  if (GWEN_BufferedIO_Close(bio)) {
-    DBG_INFO(0, "called from here");
+  /* append empty line to separate header from data */
+  rv=GWEN_Io_Layer_WriteChar(io, '\n',
+			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
+			     0,
+			     2000);
+  if (rv<0) {
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    GWEN_Buffer_free(buf);
+    return "";
   }
-  GWEN_BufferedIO_free(bio);
 
-  result=string(GWEN_Buffer_GetStart(buf),
-                GWEN_Buffer_GetUsedBytes(buf));
+  /* write data */
+  rv=GWEN_Io_Layer_WriteBytes(io,
+			      (const uint8_t*)_message.data(),
+			      _message.length(),
+			      GWEN_IO_REQUEST_FLAGS_WRITEALL,
+			      0,
+			      2000);
+  if (rv<0) {
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    GWEN_Buffer_free(buf);
+    return "";
+  }
+
+  /* append CR for better readability */
+  rv=GWEN_Io_Layer_WriteChar(io, '\n',
+			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
+			     0,
+			     2000);
+  if (rv<0) {
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    GWEN_Buffer_free(buf);
+    return "";
+  }
+
+  /* close layer */
+  rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, 0, 30000);
+  if (rv<0) {
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    GWEN_Buffer_free(buf);
+    return "";
+  }
+
+  GWEN_Io_Layer_free(io);
+  result=std::string(GWEN_Buffer_GetStart(buf),
+		     GWEN_Buffer_GetUsedBytes(buf));
   GWEN_Buffer_free(buf);
+
   return result;
 }
 
 
 
-
-
-
 LogAnalyzer::LogFile::LogFile(const string &fname)
 :_fileName(fname){
-  GWEN_BUFFEREDIO *bio;
-  GWEN_ERRORCODE err;
+  GWEN_IO_LAYER *io;
+  GWEN_FAST_BUFFER *fb;
   int fd;
   int rv;
+  uint8_t buffer[1024];
 
   fd=open(fname.c_str(), O_RDONLY);
   if (fd==-1) {
-    DBG_ERROR(0, "Error opening file \"%s\": %s",
+    DBG_ERROR(AQBANKING_LOGDOMAIN,
+	      "Error opening file \"%s\": %s",
               fname.c_str(),
               strerror(errno));
     throw Error("LogAnalyzer::Logfile::LogFile",
@@ -173,77 +196,125 @@ LogAnalyzer::LogFile::LogFile(const string &fname)
                 fname);
   }
 
-  bio=GWEN_BufferedIO_File_new(fd);
-  GWEN_BufferedIO_SetReadBuffer(bio, 0, 1024);
+  /* create io layer for this file */
+  io=GWEN_Io_LayerFile_new(fd, -1);
+  assert(io);
 
-  while (!GWEN_BufferedIO_CheckEOF(bio)) {
+  /* create fast buffer around io layer */
+  fb=GWEN_FastBuffer_new(1024, io, 0, 20000);
+
+  rv=GWEN_Io_Manager_RegisterLayer(io);
+  if (rv) {
+    DBG_ERROR(AQBANKING_LOGDOMAIN,
+	      "Internal error: Could not register io layer (%d)", rv);
+    GWEN_FastBuffer_free(fb);
+    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
+					GWEN_IO_REQUEST_FLAGS_FORCE,
+					0, 2000);
+    GWEN_Io_Layer_free(io);
+    throw Error("LogAnalyzer::Logfile::LogFile",
+		ERROR_LEVEL_NORMAL,
+		HBCI_ERROR_CODE_UNKNOWN,
+		ERROR_ADVISE_DONTKNOW,
+		"Error registering io layer",
+		fname);
+  }
+
+  for (;;) {
     Pointer<LogMessage> msg;
     GWEN_DB_NODE *hd;
     unsigned int size;
     string body;
 
+    // read header
     hd=GWEN_DB_Group_new("Header");
-    rv=GWEN_DB_ReadFromStream(hd, bio, GWEN_DB_FLAGS_HTTP);
-    if (rv) {
-      GWEN_DB_Group_free(hd);
-      GWEN_BufferedIO_free(bio);
-      throw Error("LogAnalyzer::Logfile::LogFile",
-                  ERROR_LEVEL_NORMAL,
-                  HBCI_ERROR_CODE_UNKNOWN,
-                  ERROR_ADVISE_DONTKNOW,
-                  "Error reading header",
-                  fname);
+    rv=GWEN_DB_ReadFromFastBuffer(hd, fb,
+				  GWEN_DB_FLAGS_HTTP |
+				  GWEN_DB_FLAGS_UNTIL_EMPTY_LINE);
+    if (rv<0) {
+      if (rv==GWEN_ERROR_EOF)
+	break;
+      else {
+	DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+	GWEN_DB_Group_free(hd);
+	GWEN_FastBuffer_free(fb);
+	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
+					    GWEN_IO_REQUEST_FLAGS_FORCE,
+					    0, 2000);
+	GWEN_Io_Layer_free(io);
+	throw Error("LogAnalyzer::Logfile::LogFile",
+		    ERROR_LEVEL_NORMAL,
+		    HBCI_ERROR_CODE_UNKNOWN,
+		    ERROR_ADVISE_DONTKNOW,
+		    "Error reading header",
+		    fname);
+      }
     }
     // read body
     size=GWEN_DB_GetIntValue(hd, "size", 0, 0);
     while(size) {
       string tmp;
       unsigned int lsize;
-      char buffer[1024];
 
       lsize=size;
       if (lsize>sizeof(buffer))
-        lsize=sizeof(buffer);
-      if (GWEN_BufferedIO_ReadRaw(bio, buffer, &lsize)) {
-        GWEN_DB_Group_free(hd);
-        GWEN_BufferedIO_free(bio);
-        throw Error("LogAnalyzer::Logfile::LogFile",
-                    ERROR_LEVEL_NORMAL,
-                    HBCI_ERROR_CODE_UNKNOWN,
-                    ERROR_ADVISE_DONTKNOW,
-                    "Error reading body",
-                    fname);
+	lsize=sizeof(buffer);
+
+      GWEN_FASTBUFFER_READFORCED(fb, rv, buffer, lsize);
+      if (rv<0) {
+	DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+	GWEN_DB_Group_free(hd);
+	GWEN_FastBuffer_free(fb);
+	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
+					    GWEN_IO_REQUEST_FLAGS_FORCE,
+					    0, 2000);
+	GWEN_Io_Layer_free(io);
+	throw Error("LogAnalyzer::Logfile::LogFile",
+		    ERROR_LEVEL_NORMAL,
+		    HBCI_ERROR_CODE_UNKNOWN,
+		    ERROR_ADVISE_DONTKNOW,
+		    "Error reading body",
+		    fname);
       }
-      body+=string(buffer, lsize);
+      body+=string((const char*)buffer, lsize);
       size-=lsize;
     } // while
-    if (GWEN_BufferedIO_ReadChar(bio)==-1) {
-      GWEN_DB_Group_free(hd);
-      GWEN_BufferedIO_free(bio);
-      throw Error("LogAnalyzer::Logfile::LogFile",
-                  ERROR_LEVEL_NORMAL,
-                  HBCI_ERROR_CODE_UNKNOWN,
-                  ERROR_ADVISE_DONTKNOW,
-                  "Error reading newline after body",
-                  fname);
-    }
-    msg=new LogMessage(hd, body);
-    DBG_INFO(0, "Adding message");
-    _logMessages.push_back(msg);
-  } // while
 
-  err=GWEN_BufferedIO_Close(bio);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_INFO(0, "called from here");
-    GWEN_BufferedIO_free(bio);
-    throw Error("LogAnalyzer::Logfile::LogFile",
-                ERROR_LEVEL_NORMAL,
-                HBCI_ERROR_CODE_UNKNOWN,
-                ERROR_ADVISE_DONTKNOW,
-                "Error closing file",
-                fname);
+    /* read closing LF */
+    GWEN_FASTBUFFER_READFORCED(fb, rv, buffer, 1);
+    if (rv<0) {
+      if (rv==GWEN_ERROR_EOF) {
+	DBG_INFO(AQBANKING_LOGDOMAIN, "EOF met");
+	break;
+      }
+      else {
+	DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+	GWEN_DB_Group_free(hd);
+	GWEN_FastBuffer_free(fb);
+	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
+					    GWEN_IO_REQUEST_FLAGS_FORCE,
+					    0, 2000);
+	GWEN_Io_Layer_free(io);
+	throw Error("LogAnalyzer::Logfile::LogFile",
+		    ERROR_LEVEL_NORMAL,
+		    HBCI_ERROR_CODE_UNKNOWN,
+		    ERROR_ADVISE_DONTKNOW,
+		    "Error reading body",
+		    fname);
+      }
+    }
+    else {
+      msg=new LogMessage(hd, body);
+      DBG_INFO(AQBANKING_LOGDOMAIN, "Adding message");
+      _logMessages.push_back(msg);
+    }
   }
-  GWEN_BufferedIO_free(bio);
+
+  GWEN_FastBuffer_free(fb);
+  GWEN_Io_Layer_DisconnectRecursively(io, NULL,
+				      0,
+				      0, 2000);
+  GWEN_Io_Layer_free(io);
 }
 
 
@@ -269,9 +340,9 @@ string LogAnalyzer::_getPath() {
   dname+=_bankCode;
   dname+="/logs/";
 
-  DBG_INFO(0, "Searching in \"%s\"", dname.c_str());
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Searching in \"%s\"", dname.c_str());
   if (dname.length()>=sizeof(buffer)) {
-    DBG_ERROR(0, "Path too long");
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "Path too long");
     return "";
   }
 
@@ -295,7 +366,7 @@ void *LogAnalyzer::_handlePathElement(const char *entry,
 
   p=(char*)data;
   if ((strlen(p)+strlen(entry)+2)>=256) {
-    DBG_ERROR(0, "Buffer too small");
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "Buffer too small");
     return 0;
   }
   strcat(p, "/");
@@ -303,68 +374,71 @@ void *LogAnalyzer::_handlePathElement(const char *entry,
 
   // check for existence of the file/folder
 
-  DBG_DEBUG(0, "Checking entry \"%s\"", p);
+  DBG_DEBUG(AQBANKING_LOGDOMAIN, "Checking entry \"%s\"", p);
   if (stat(p, &st)) {
     exists=false;
-    DBG_DEBUG(0, "stat: %s (%s)", strerror(errno), p);
+    DBG_DEBUG(AQBANKING_LOGDOMAIN, "stat: %s (%s)", strerror(errno), p);
     if ((flags & GWEN_PATH_FLAGS_PATHMUSTEXIST) ||
         ((flags & GWEN_PATH_FLAGS_LAST) &&
          (flags & GWEN_PATH_FLAGS_NAMEMUSTEXIST))) {
-      DBG_ERROR(0, "Path \"%s\" does not exist (it should)", p);
+      DBG_ERROR(AQBANKING_LOGDOMAIN,
+		"Path \"%s\" does not exist (it should)", p);
       return 0;
     }
   }
   else {
-    DBG_DEBUG(0, "Checking for type");
+    DBG_DEBUG(AQBANKING_LOGDOMAIN, "Checking for type");
     exists=true;
     if (flags & GWEN_PATH_FLAGS_VARIABLE) {
       if (!S_ISREG(st.st_mode)) {
-        DBG_ERROR(0, "%s not a regular file", p);
+        DBG_ERROR(AQBANKING_LOGDOMAIN, "%s not a regular file", p);
         return 0;
       }
     }
     else {
       if (!S_ISDIR(st.st_mode)) {
-	DBG_ERROR(0, "%s not a direcory", p);
+	DBG_ERROR(AQBANKING_LOGDOMAIN, "%s not a direcory", p);
         return 0;
       }
     }
     if ((flags & GWEN_PATH_FLAGS_PATHMUSTNOTEXIST) ||
         ((flags & GWEN_PATH_FLAGS_LAST) &&
          (flags & GWEN_PATH_FLAGS_NAMEMUSTNOTEXIST))) {
-      DBG_ERROR(0, "Path \"%s\" does not exist (it should)", p);
+      DBG_ERROR(AQBANKING_LOGDOMAIN,
+		"Path \"%s\" does not exist (it should)", p);
       return 0;
     }
   } // if stat is ok
 
   if (!exists) {
-    DBG_DEBUG(0, "Entry \"%s\" does not exist", p);
+    DBG_DEBUG(AQBANKING_LOGDOMAIN,
+	      "Entry \"%s\" does not exist", p);
     if (flags & GWEN_PATH_FLAGS_VARIABLE) {
       // create file
       int fd;
 
-      DBG_DEBUG(0, "Creating file \"%s\"", p);
+      DBG_DEBUG(AQBANKING_LOGDOMAIN, "Creating file \"%s\"", p);
       fd=open(p, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
       if (fd==-1) {
-        DBG_ERROR(0, "open: %s (%s)", strerror(errno), p);
+        DBG_ERROR(AQBANKING_LOGDOMAIN, "open: %s (%s)", strerror(errno), p);
         return 0;
       }
       close(fd);
-      DBG_DEBUG(0, "Sucessfully created");
+      DBG_DEBUG(AQBANKING_LOGDOMAIN, "Sucessfully created");
     }
     else {
       // create dir
-      DBG_DEBUG(0, "Creating folder \"%s\"", p);
+      DBG_DEBUG(AQBANKING_LOGDOMAIN, "Creating folder \"%s\"", p);
       if (mkdir(p, S_IRWXU)) {
-        DBG_ERROR(0, "mkdir: %s (%s)", strerror(errno), p);
+        DBG_ERROR(AQBANKING_LOGDOMAIN, "mkdir: %s (%s)", strerror(errno), p);
         return 0;
       }
     }
   } // if exists
   else {
-    DBG_DEBUG(0, "Entry \"%s\" exists", p);
+    DBG_DEBUG(AQBANKING_LOGDOMAIN, "Entry \"%s\" exists", p);
   }
-  DBG_DEBUG(0, "Returning this: %s", p);
+  DBG_DEBUG(AQBANKING_LOGDOMAIN, "Returning this: %s", p);
   return p;
 }
 
@@ -376,7 +450,7 @@ LogAnalyzer::LogAnalyzer(const string &baseDir,
 :_baseDir(baseDir)
 ,_country(country)
 ,_bankCode(bank) {
-  GWEN_DIRECTORYDATA *dlogs;
+  GWEN_DIRECTORY *dlogs;
   string dname;
 
   dname=_getPath();
@@ -396,7 +470,8 @@ LogAnalyzer::LogAnalyzer(const string &baseDir,
             string fname;
 
             fname=dname+"/"+nbuffer;
-            DBG_NOTICE(0, "Added file \"%s\"", fname.c_str());
+	    DBG_NOTICE(AQBANKING_LOGDOMAIN,
+		       "Added file \"%s\"", fname.c_str());
             _logFiles.push_back(fname);
           }
         }
