@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qt3_debug.cpp 622 2005-09-19 13:04:42Z cstim $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -37,7 +37,7 @@ int main(int argc, char **argv) {
   string hdir;
   QTranslator translator(0);
 
-  GWEN_Logger_SetLevel(0, GWEN_LoggerLevelNotice);
+  GWEN_Logger_SetLevel(0, GWEN_LoggerLevel_Notice);
   //GWEN_Logger_SetLevel(GWEN_LOGDOMAIN, GWEN_LoggerLevelNotice);
   //GWEN_Logger_SetLevel("aqhbci", GWEN_LoggerLevelNotice);
 
@@ -56,7 +56,7 @@ int main(int argc, char **argv) {
 
   hdir=QDir::homeDirPath().local8Bit().data();
   hdir+="/";
-  hdir+=".banking";
+  hdir+=".aqbanking";
 
   hb=new LogManager(hdir.c_str(), 0, "LogManager", false);
   app.setMainWidget(hb);
