@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: provider.h 804 2006-01-19 01:07:49Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -31,7 +31,8 @@ typedef struct AO_PROVIDER AO_PROVIDER;
 AQOFXCONNECT_API AB_PROVIDER *AO_Provider_new(AB_BANKING *ab);
 
 AQOFXCONNECT_API int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
-                                                 AB_USER *u);
+						 AB_USER *u,
+						 uint32_t guiid);
 
 #ifdef __cplusplus
 }
