@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgtabpageaccountofx.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cfgtabpageaccountofx.h,v 1.1 2006/01/26 03:34:55 aquamaniac Exp $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
