@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dtaus_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: dtaus_p.h,v 1.3 2005/08/17 20:09:40 aquamaniac Exp $
+ cvs         : $Id$
  begin       : Thu Apr 29 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -25,7 +25,9 @@ GWEN_DBIO *AHB_DTAUS_Factory(GWEN_PLUGIN *pl);
 GWEN_DBIO_CHECKFILE_RESULT AHB_DTAUS__ReallyCheckFile(GWEN_BUFFER *src,
                                                       unsigned int pos);
 GWEN_DBIO_CHECKFILE_RESULT AHB_DTAUS__CheckFile(GWEN_DBIO *dbio,
-                                                const char *fname);
+						const char *fname,
+						uint32_t guiid,
+						int msecs);
 
 
 
