@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: swift940_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: swift940_p.h,v 1.4 2006/01/25 18:08:20 aquamaniac Exp $
+ cvs         : $Id$
  begin       : Fri Apr 02 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -20,23 +20,23 @@
 
 
 int AHB_SWIFT940_Parse_25(const AHB_SWIFT_TAG *tg,
-                          GWEN_TYPE_UINT32 flags,
+                          uint32_t flags,
                           GWEN_DB_NODE *data,
                           GWEN_DB_NODE *cfg);
 
 
 int AHB_SWIFT940_Parse_86(const AHB_SWIFT_TAG *tg,
-                          GWEN_TYPE_UINT32 flags,
+                          uint32_t flags,
                           GWEN_DB_NODE *data,
                           GWEN_DB_NODE *cfg);
 
 int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
-                          GWEN_TYPE_UINT32 flags,
+                          uint32_t flags,
                           GWEN_DB_NODE *data,
                           GWEN_DB_NODE *cfg);
 
 int AHB_SWIFT940_Parse_6_0_2(const AHB_SWIFT_TAG *tg,
-                             GWEN_TYPE_UINT32 flags,
+                             uint32_t flags,
                              GWEN_DB_NODE *data,
                              GWEN_DB_NODE *cfg);
 
